@@ -1,9 +1,9 @@
-from typing import Optional, List, Dict, Any
+from typing import Any, Dict, List, Optional
 
-from numpy import ma
 import numpy as np
 import pandas as pd
 import xtgeo
+from numpy import ma
 from plotly.subplots import make_subplots
 
 from .._utils.colors import hex_to_rgba
@@ -88,11 +88,9 @@ class XSectionFigure:
     @property
     def data(self) -> Any:
         """The Plotly figure traces"""
-        # pylint: disable=line-too-long
         # TODO: According to
         # https://plotly.com/python-api-reference/generated/plotly.graph_objects.Figure.html
         # this can return very different types.
-        # pylint: enable=line-too-long
         return self._figure.data
 
     @property
@@ -223,9 +221,8 @@ class XSectionFigure:
             hvals_copy = ma.masked_where(zonevals != zone, hvals)
             color = self._surfacecolors[i % len(self._surfacecolors)]
             self._figure.add_trace(
-                {  # pylint: disable=no-member
+                {
                     "x": hvals_copy.compressed(),
-                    # pylint: disable=no-member
                     "y": zvals_copy.compressed(),
                     "line": {"width": 10, "color": color},
                     "fillcolor": color,
@@ -370,7 +367,7 @@ class XSectionFigure:
             1,
         )
 
-    # pylint: disable=too-many-locals, unused-argument
+    # pylint: disable=unused-argument
     def plot_grid3d(
         self,
         vmin: Optional[float] = None,
@@ -430,7 +427,7 @@ class XSectionFigure:
         fill: bool = False,
         surfaces: List[xtgeo.RegularSurface] = None,
         surfacenames: Optional[List[str]] = None,
-    ) -> None:  # pylint: disable=too-many-branches, too-many-statements
+    ) -> None:
 
         """Input a surface list (ordered from top to base) , and plot them."""
 
