@@ -1,33 +1,28 @@
 # pylint: disable=too-many-lines
-from typing import List, Tuple, Callable
 import io
 import json
-from uuid import uuid4
 from pathlib import Path
-import defusedxml.ElementTree as ET
+from typing import Callable, List, Tuple
+from uuid import uuid4
 
-import numpy as np
-import xtgeo
-import dash
-import dash_table
-from dash.dependencies import Input, Output, State
-import dash_html_components as html
-import dash_core_components as dcc
 import dash_bootstrap_components as dbc
+import defusedxml.ElementTree as ET
+import numpy as np
 import webviz_core_components as wcc
 import webviz_subsurface_components
-
-from webviz_config.webviz_assets import WEBVIZ_ASSETS
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
-from webviz_config.webviz_store import webvizstore
+import xtgeo
+from dash import Dash, Input, Output, State, callback_context, dash_table, dcc, html
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.deprecation_decorators import deprecated_plugin
+from webviz_config.webviz_assets import WEBVIZ_ASSETS
+from webviz_config.webviz_store import webvizstore
 
 import webviz_subsurface
-from webviz_subsurface._models import SurfaceLeafletModel
 from webviz_subsurface._datainput.well import get_well_layers
-from ._huv_xsection import HuvXsection
+from webviz_subsurface._models import SurfaceLeafletModel
+
 from ._huv_table import FilterTable
+from ._huv_xsection import HuvXsection
 
 
 @deprecated_plugin(
@@ -46,10 +41,10 @@ class HorizonUncertaintyViewer(WebvizPluginABC):
     * **`planned_wells_dir`:** Path to folder with planned well files.
        Make sure that all planned wells have format 'ROXAR RMS well'."""
 
-    # pylint: disable=too-many-locals,too-many-instance-attributes
+    # pylint: disable=too-many-instance-attributes
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         basedir: Path,
         planned_wells_dir: Path = None,
@@ -112,9 +107,11 @@ class HorizonUncertaintyViewer(WebvizPluginABC):
         # Wellfiles and planned wells
         self.planned_wells = {}
         if planned_wells_dir is not None:
-            self.planned_wells = {wf: xtgeo.Well(wf) for wf in self.planned_wellfiles}
+            self.planned_wells = {
+                wf: xtgeo.well_from_file(wfile=wf) for wf in self.planned_wellfiles
+            }
 
-        self.wells = {wf: xtgeo.Well(wf) for wf in self.wellfiles}
+        self.wells = {wf: xtgeo.well_from_file(wfile=wf) for wf in self.wellfiles}
 
         # Store current layers
         self.state = {"switch": False}
@@ -495,7 +492,6 @@ class HorizonUncertaintyViewer(WebvizPluginABC):
                         "zIndex": -9999,
                     },
                     children=[
-                        # pylint: disable=no-member
                         webviz_subsurface_components.LeafletMap(
                             id=self.ids("layered-map"),
                             layers=[],
@@ -574,7 +570,7 @@ class HorizonUncertaintyViewer(WebvizPluginABC):
         )
 
     # pylint: disable=too-many-statements
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output(self.ids("layered-map"), "layers"),
             [
@@ -648,7 +644,7 @@ class HorizonUncertaintyViewer(WebvizPluginABC):
         ):
             """Renders cross section view from wellfile or polyline drawn in map view"""
             _ = n_apply_sfc, n_apply_well
-            ctx = dash.callback_context
+            ctx = callback_context
             if wellfile in self.wellfiles:
                 well = self.wells[wellfile]
                 is_planned = False
@@ -756,7 +752,7 @@ class HorizonUncertaintyViewer(WebvizPluginABC):
                 State(self.ids("columns-checklist"), "value"),
             ],  # columns list
         )
-        # pylint: disable=unused-variable, unused-argument
+        # pylint: disable=unused-argument
         def display_output(n_clicks, column_list):
             """Renders wellpoints table from csv file"""
             wellpoints_df = self.df_well_target_points.update_wellpoints_df(column_list)
