@@ -4,20 +4,16 @@
 #
 ########################################
 
-from typing import Callable, Dict, List, Tuple, Union, Any
+from typing import Any, Callable, Dict, List, Tuple, Union
 
 import pandas as pd
-import dash
-import dash_html_components as html
-from dash.dependencies import Input, Output, State
-from dash.exceptions import PreventUpdate
-import dash_core_components as dcc
 import webviz_core_components as wcc
+from dash import Dash, Input, Output, State, callback_context, dcc, html
+from dash.exceptions import PreventUpdate
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
 
-from .._datainput.pvt_data import load_pvt_dataframe, load_pvt_csv
+from .._datainput.pvt_data import load_pvt_csv, load_pvt_dataframe
 
 
 class PvtPlot(WebvizPluginABC):
@@ -69,7 +65,7 @@ class PvtPlot(WebvizPluginABC):
 
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         ensembles: List[str],
         pvt_relative_file_path: str = None,
@@ -317,7 +313,7 @@ class PvtPlot(WebvizPluginABC):
             ],
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output(self.uuid("graphs"), "children"),
             [
@@ -385,7 +381,7 @@ class PvtPlot(WebvizPluginABC):
             visibility_options = self.plot_visibility_options(self.phases[phase])
             return (
                 [{"label": l, "value": v} for v, l in visibility_options.items()],
-                [value for value in values if value in visibility_options.keys()],
+                [value for value in values if value in visibility_options],
             )
 
         @app.callback(
@@ -396,13 +392,12 @@ class PvtPlot(WebvizPluginABC):
             [Input(self.uuid("color_by"), "value")],
         )
         def _set_ensemble_selector(color_by: str) -> Tuple[bool, Union[str, List[str]]]:
-            # pylint: disable=unused-argument
             """If ensemble is selected as color by, set the ensemble
             selector to allow multiple selections
             """
             if (
-                dash.callback_context.triggered is None
-                or not dash.callback_context.triggered[0]["prop_id"].split(".")[0]
+                callback_context.triggered is None
+                or not callback_context.triggered[0]["prop_id"].split(".")[0]
             ):
                 raise PreventUpdate
 
@@ -424,13 +419,12 @@ class PvtPlot(WebvizPluginABC):
         )
         # pylint:
         def _set_pvtnum_selector(color_by: str) -> Tuple[bool, Union[str, List[str]]]:
-            # pylint: disable=unused-argument
             """If pvtnum is selected as color by, set the pvtnum
             selector to allow multiple selections
             """
             if (
-                dash.callback_context.triggered is None
-                or not dash.callback_context.triggered[0]["prop_id"].split(".")[0]
+                callback_context.triggered is None
+                or not callback_context.triggered[0]["prop_id"].split(".")[0]
             ):
                 raise PreventUpdate
 
@@ -788,6 +782,7 @@ def create_hovertext(
 ) -> str:
     hovertext: Union[str, list] = ""
     if phase == "OIL":
+        # pylint: disable=consider-using-f-string
         hovertext = "{} Pvtnum: {}<br />Realization: {}, Ensemble: {}".format(
             f"Rs = {ratio_value}" if keyword == "PVTO" else "",
             group if color_by == "PVTNUM" else constant_group,
@@ -795,6 +790,7 @@ def create_hovertext(
             group if color_by == "ENSEMBLE" else constant_group,
         )
     elif phase == "GAS":
+        # pylint: disable=consider-using-f-string
         hovertext = (
             "{}"
             "Pvtnum: "
